# Brain

Body service that handles users and permissions.

This code comes without documentation as it's not meant to be used by anyone
outside of Ouroboros Coding Inc. Please see LICENSE for further information.
